Learn R Programming

chngpt (version 2016.7-9)

dat.mtct: An Example Dataset

Description

A dataset from the immune correlates study of Maternal To Child Transmission of HIV-1

Usage

data("dat.mtct")

Arguments

Format

A data frame with 236 observations on the following 3 variables.
y
a numeric vector
birth
a factor with levels C-section Vaginal
NAb_SF162LS
a numeric vector

References

Permar, S. R., Fong, Y., Nathan Vandergrift, Genevieve G. Fouda, Peter Gilbert, Georgia D. Tomaras, Feng Gao and Barton F. Haynes et al. (2015) Maternal HIV-1 Envelope variable loop 3-specific IgG responses and reduced risk of perinatal transmission. Journal of Clinical Investigation, 125(7):2702:2706.

Fong, Y., Huang, Y., Gilbert, P. (2015) Estimation and hypothesis testing under four types of change point models using chngpt, under review.

Examples

Run this code
data(dat.mtct)
## maybe str(dat.mtct) ; plot(dat.mtct) ...

Run the code above in your browser using DataLab