Rdocumentation
powered by
Learn R Programming
chngpt (version 2016.7-9)
sim.pastor: Simulate data according to one of the scenarios considered in Pastor-Barriuso et al 2003
Description
Simulate data according to one of the scenarios considered in Pastor-Barriuso et al 2003
Usage
sim.pastor(seed)
Arguments
seed
Seed for the random number generator.
Value
A data frame with columns: y, x.star, x.star.expit, and x.bin.med (x.star dichotomized at median).
Examples
Run this code
dat=sim.pastor(seed=
1
)
Run the code above in your browser using
DataLab